# `royalnet` [![PyPI](https://img.shields.io/pypi/v/royalnet.svg)](https://pypi.org/project/royalnet/)

The fifth rewrite of the Royal Network!

It has a lot of submodules, many of which may be used in other bots.

[Documentation available here](https://royal-games.github.io/royalnet/html/index.html).
